.. image:: https://img.shields.io/pypi/v/bg-kube.svg
    :target: https://pypi.python.org/pypi/bg-kube

.. image:: https://travis-ci.org/stphivos/bg-kube.svg
    :target: https://travis-ci.org/stphivos/bg-kube

.. image:: https://codecov.io/github/stphivos/bg-kube/coverage.svg
    :target: https://codecov.io/github/stphivos/bg-kube

*******
bg-kube
*******
